@@ -12,6 +12,7 @@ func init() {
 		">>":                    "greater-than-greater-than_commands_docgen.go",
 		">":                     "greater-than_commands_docgen.go",
 		"@[":                    "range_commands_docgen.go",
+		"autoglob":              "autoglob_commands_docgen.go",
 		"[[":                    "element_commands_docgen.go",
 		"[":                     "index_commands_docgen.go",
 		"a":                     "a_commands_docgen.go",
@@ -68,6 +69,7 @@ func init() {
 		"left":                  "left_commands_docgen.go",
 		"let":                   "let_commands_docgen.go",
 		"lockfile":              "lockfile_commands_docgen.go",
+		"man-get-flags":         "man-get-flags_commands_docgen.go",
 		"man-summary":           "man-summary_commands_docgen.go",
 		"map":                   "map_commands_docgen.go",
 		"match":                 "match_commands_docgen.go",
@@ -96,6 +98,7 @@ func init() {
 		"read":                  "read_commands_docgen.go",
 		"regexp":                "regexp_commands_docgen.go",
 		"right":                 "right_commands_docgen.go",
+		"runmode":               "runmode_commands_docgen.go",
 		"runtime":               "runtime_commands_docgen.go",
 		"rx":                    "rx_commands_docgen.go",
 		"set":                   "set_commands_docgen.go",
@@ -104,8 +107,6 @@ func init() {
 		"suffix":                "suffix_commands_docgen.go",
 		"summary":               "summary_commands_docgen.go",
 		"switch":                "switch_commands_docgen.go",
-		"swivel-datatype":       "swivel-datatype_commands_docgen.go",
-		"swivel-table":          "swivel-table_commands_docgen.go",
 		"ta":                    "ta_commands_docgen.go",
 		"tabulate":              "tabulate_commands_docgen.go",
 		"test":                  "test_commands_docgen.go",
