@@ -158,6 +158,7 @@ func init() {
 		"and":                   "and",
 		"!and":                  "and",
 		"append":                "append",
+		"list.append":           "append",
 		"args":                  "args",
 		"autocomplete":          "autocomplete",
 		"bexists":               "bexists",
@@ -217,7 +218,9 @@ func init() {
 		"!if":                   "if",
 		"ja":                    "ja",
 		"jsplit":                "jsplit",
+		"list.split":            "jsplit",
 		"left":                  "left",
+		"list.left":             "left",
 		"let":                   "let",
 		"lockfile":              "lockfile",
 		"man-get-flags":         "man-get-flags",
@@ -225,9 +228,12 @@ func init() {
 		"map":                   "map",
 		"match":                 "match",
 		"!match":                "match",
+		"list.string":           "match",
 		"method":                "method",
 		"msort":                 "msort",
+		"list.sort":             "msort",
 		"mtac":                  "mtac",
+		"list.reverse":          "mtac",
 		"murex-docs":            "murex-docs",
 		"murex-package":         "murex-package",
 		"murex-parser":          "murex-parser",
@@ -246,7 +252,9 @@ func init() {
 		"!pipe":                 "pipe",
 		"post":                  "post",
 		"prefix":                "prefix",
+		"list.prefix":           "prefix",
 		"prepend":               "prepend",
+		"list.prepend":          "prepend",
 		"pretty":                "pretty",
 		"private":               "private",
 		"pt":                    "pt",
@@ -254,7 +262,9 @@ func init() {
 		"read":                  "read",
 		"regexp":                "regexp",
 		"!regexp":               "regexp",
+		"list.regex":            "regexp",
 		"right":                 "right",
+		"list.right":            "right",
 		"runmode":               "runmode",
 		"runtime":               "runtime",
 		"builtins":              "runtime",
@@ -266,6 +276,7 @@ func init() {
 		".":                     "source",
 		"struct-keys":           "struct-keys",
 		"suffix":                "suffix",
+		"list.suffix":           "suffix",
 		"summary":               "summary",
 		"!summary":              "summary",
 		"switch":                "switch",
