@@ -3,9 +3,11 @@ package shell
 import (
 	"fmt"
 
+	"github.com/lmorg/murex/app"
 	"github.com/lmorg/murex/lang"
 	"github.com/lmorg/murex/lang/types"
 	"github.com/lmorg/murex/utils"
+	"github.com/lmorg/murex/utils/ansititle"
 )
 
 func getPrompt() {
@@ -60,6 +62,37 @@ func getMultilinePrompt(nLines int) {
 	Prompt.SetPrompt(string(b))
 }
 
+func writeTitlebar() {
+	var (
+		err, err2 error
+		exitNum   int
+		b         []byte
+	)
+
+	prompt, err := lang.ShellProcess.Config.Get("shell", "titlebar-func", types.CodeBlock)
+	if err == nil {
+		fork := lang.ShellProcess.Fork(lang.F_FUNCTION | lang.F_BACKGROUND | lang.F_NO_STDIN | lang.F_CREATE_STDOUT | lang.F_NO_STDERR)
+		fork.Name.Set("(titlebar-func)")
+		fork.Execute([]rune(prompt.(string)))
+
+		b, err2 = fork.Stdout.ReadAll()
+		b = utils.CrLfTrim(b)
+	}
+
+	if exitNum != 0 || err != nil || len(b) == 0 || err2 != nil {
+		lang.ShellProcess.Stderr.Writeln([]byte("Invalid titlebar-func. Block returned false."))
+		ansititle.Write([]byte(app.Name))
+		if tmux, _ := lang.ShellProcess.Config.Get("proc", "echo-tmux", types.Boolean); tmux.(bool) {
+			ansititle.Tmux([]byte(app.Name))
+		}
+	}
+
+	ansititle.Write(b)
+	if tmux, _ := lang.ShellProcess.Config.Get("proc", "echo-tmux", types.Boolean); tmux.(bool) {
+		ansititle.Tmux(b)
+	}
+}
+
 // ConfigReadGetCursorPos is a dynamic config wrapper function for Prompt.EnableGetCursorPos
 func ConfigReadGetCursorPos() (interface{}, error) {
 	return Prompt.EnableGetCursorPos, nil
@@ -67,12 +100,12 @@ func ConfigReadGetCursorPos() (interface{}, error) {
 
 // ConfigWriteGetCursorPos is a dynamic config wrapper function for Prompt.EnableGetCursorPos
 func ConfigWriteGetCursorPos(v interface{}) error {
-	switch v.(type) {
+	switch v := v.(type) {
 	case bool:
-		Prompt.EnableGetCursorPos = v.(bool)
+		Prompt.EnableGetCursorPos = v
 
 	case string:
-		switch v.(string) {
+		switch v {
 		case types.TrueString:
 			Prompt.EnableGetCursorPos = true
 
@@ -80,11 +113,11 @@ func ConfigWriteGetCursorPos(v interface{}) error {
 			Prompt.EnableGetCursorPos = false
 
 		default:
-			return fmt.Errorf("Expecting 'true' or 'false'. Instead received '%s'", v.(string))
+			return fmt.Errorf("expecting 'true' or 'false'. Instead received '%s'", v)
 		}
 
 	default:
-		return fmt.Errorf("Expecting boolean value. Instead received %T", v)
+		return fmt.Errorf("expecting boolean value. Instead received %T", v)
 	}
 
 	return nil
